How to setup a laptop for a Developer

## Install Ubuntu/Kubuntu


> [!NOTE] Fix BIOS Settings
> You may need to change the Storage controller from Intel RST (RAID) to ACHI if the storage device isn't detected in the Ubuntu installer.
> 


> [!TIP] TIP
> Install the ssh server to remotely configure device
> ````bash
> sudo apt install openssh-server
> ````


## Dev Tools

Add packages necessary for Dev Tools

```bash
sudo apt install php8.1-xml make php8.1-cli curl
```


## AWS CLI

Install AWS CLI
```bash
curl "https://awscli.amazonaws.com/awscli-exe-linux-x86_64.zip" -o "awscliv2.zip"
unzip awscliv2.zip
sudo ./aws/install
```


## IntelliJ

Install Idea Toolbox for IntelliJ
Download Toolbox from `https://www.jetbrains.com/toolbox-app/`
```bash
cd ~/Downloads
tar xvzf jetbrains-toolbox-*
```
cd into the new jetbrains directory and run the installer
After Toolbox launches, install the IntelliJ Ultimate application

## Docker

> [!NOTE] Official Docker Instructions for Ubuntu
> https://docs.docker.com/engine/install/ubuntu/


Uninstall old versions
```bash
sudo apt-get remove docker docker-engine docker.io containerd runc
```


Setup Docker Repo

1.  Install required packages

```bash
sudo apt-get update
sudo apt-get install ca-certificates curl gnupg
```

2. Add Docker's official GPG Key

```bash
sudo install -m 0755 -d /etc/apt/keyrings
curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo gpg --dearmor -o /etc/apt/keyrings/docker.gpg
sudo chmod a+r /etc/apt/keyrings/docker.gpg
```

3. Set up repository

```bash
echo \
  "deb [arch="$(dpkg --print-architecture)" signed-by=/etc/apt/keyrings/docker.gpg] https://download.docker.com/linux/ubuntu \
  "$(. /etc/os-release && echo "$VERSION_CODENAME")" stable" | \
  sudo tee /etc/apt/sources.list.d/docker.list > /dev/null
```

4. Install Docker Engine

```bash
sudo apt-get update
sudo apt-get install docker-ce docker-ce-cli containerd.io docker-buildx-plugin docker-compose-plugin
```

5. Verify that the Docker Engine installation is successful

```bash
sudo docker run hello-world
```

6. Manage Docker as a non-root user

```bash
sudo groupadd docker
sudo usermod -aG docker $USER
newgrp docker
docker run hello-world
```

7.  Configure Docker to start on boot with systemd

```bash
sudo systemctl enable docker.service
sudo systemctl enable containerd.service
```

